@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +21,7 @@
 
 #include <QDialog>
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class PlainTextEditorWidget;
 }
 class TranslatorDebugDialog : public QDialog
@@ -33,14 +33,12 @@ public:
 
     void setDebug(const QString &debugStr);
 
-private Q_SLOTS:
-    void slotSaveAs();
-
 private:
+    void slotSaveAs();
     void readConfig();
     void writeConfig();
-    KPIMTextEdit::PlainTextEditorWidget *mEdit;
-    QPushButton *mUser1Button;
+    KPIMTextEdit::PlainTextEditorWidget *mEdit = nullptr;
+    QPushButton *mUser1Button = nullptr;
 };
 
 #endif // TRANSLATORDEBUGDIALOG_H
