@@ -1,10 +1,11 @@
 /*
 
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
-  The program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -51,11 +52,9 @@ class Q_DECL_HIDDEN TranslatorWidget::TranslatorWidgetPrivate
 {
 public:
     TranslatorWidgetPrivate()
-        : abstractTranslator(nullptr),
-          languageSettingsChanged(false),
-          standalone(true)
     {
     }
+
     ~TranslatorWidgetPrivate()
     {
         delete abstractTranslator;
@@ -66,19 +65,19 @@ public:
 
     QMap<QString, QMap<QString, QString> > listLanguage;
     QByteArray data;
-    TranslatorTextEdit *inputText;
-    KPIMTextEdit::PlainTextEditorWidget *translatedText;
-    TranslatorResultTextEdit *translatorResultTextEdit;
-    MinimumComboBox *from;
-    MinimumComboBox *to;
-    QPushButton *translate;
-    QPushButton *clear;
-    PimCommon::GoogleTranslator *abstractTranslator;
-    KPIM::ProgressIndicatorWidget *progressIndictor;
-    QPushButton *invert;
-    QSplitter *splitter;
-    bool languageSettingsChanged;
-    bool standalone;
+    TranslatorTextEdit *inputText = nullptr;
+    KPIMTextEdit::PlainTextEditorWidget *translatedText = nullptr;
+    TranslatorResultTextEdit *translatorResultTextEdit = nullptr;
+    MinimumComboBox *from = nullptr;
+    MinimumComboBox *to = nullptr;
+    QPushButton *translate = nullptr;
+    QPushButton *clear = nullptr;
+    PimCommon::GoogleTranslator *abstractTranslator = nullptr;
+    KPIM::ProgressIndicatorWidget *progressIndictor = nullptr;
+    QPushButton *invert = nullptr;
+    QSplitter *splitter = nullptr;
+    bool languageSettingsChanged = false;
+    bool standalone = true;
 };
 
 void TranslatorWidget::TranslatorWidgetPrivate::fillToCombobox(const QString &lang)
@@ -102,8 +101,8 @@ void TranslatorWidget::TranslatorWidgetPrivate::initLanguage()
 }
 
 TranslatorResultTextEdit::TranslatorResultTextEdit(QWidget *parent)
-    : KPIMTextEdit::PlainTextEditor(parent),
-      mResultFailed(false)
+    : KPIMTextEdit::PlainTextEditor(parent)
+    , mResultFailed(false)
 {
     setReadOnly(true);
 }
@@ -156,15 +155,15 @@ void TranslatorTextEdit::dropEvent(QDropEvent *event)
 }
 
 TranslatorWidget::TranslatorWidget(QWidget *parent)
-    : QWidget(parent),
-      d(new TranslatorWidgetPrivate)
+    : QWidget(parent)
+    , d(new TranslatorWidgetPrivate)
 {
     init();
 }
 
 TranslatorWidget::TranslatorWidget(const QString &text, QWidget *parent)
-    : QWidget(parent),
-      d(new TranslatorWidgetPrivate)
+    : QWidget(parent)
+    , d(new TranslatorWidgetPrivate)
 {
     init();
     d->inputText->setPlainText(text);
@@ -208,12 +207,12 @@ void TranslatorWidget::readConfig()
     const QList<int> size = {100, 400};
     d->splitter->setSizes(myGroup.readEntry("mainSplitter", size));
     d->invert->setEnabled(from != QLatin1String("auto"));
-
 }
 
 void TranslatorWidget::init()
 {
     d->abstractTranslator = new GoogleTranslator();
+    d->abstractTranslator->setParentWidget(this);
     connect(d->abstractTranslator, &PimCommon::GoogleTranslator::translateDone, this, &TranslatorWidget::slotTranslateDone);
     connect(d->abstractTranslator, &PimCommon::GoogleTranslator::translateFailed, this, &TranslatorWidget::slotTranslateFailed);
 
@@ -243,7 +242,7 @@ void TranslatorWidget::init()
     hboxLayout->addWidget(label);
     d->to = new MinimumComboBox;
     d->to->setObjectName(QStringLiteral("to"));
-    connect(d->to, static_cast<void (MinimumComboBox::*)(int)>(&MinimumComboBox::currentIndexChanged), this, &TranslatorWidget::slotConfigChanged);
+
     hboxLayout->addWidget(d->to);
 
     KSeparator *separator = new KSeparator;
@@ -273,13 +272,11 @@ void TranslatorWidget::init()
     hboxLayout->addWidget(d->translate);
     connect(d->translate, &QPushButton::clicked, this, &TranslatorWidget::slotTranslate);
 
-#if !defined(NDEBUG)
-    if (!qEnvironmentVariableIsEmpty("KDEPIM_TRANSLATE_DEBUG")) {
+    if (!qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING")) {
         QPushButton *debugButton = new QPushButton(i18n("Debug"));
         hboxLayout->addWidget(debugButton);
         connect(debugButton, &QPushButton::clicked, this, &TranslatorWidget::slotDebug);
     }
-#endif
 
     d->progressIndictor = new KPIM::ProgressIndicatorWidget(this);
     hboxLayout->addWidget(d->progressIndictor);
@@ -307,19 +304,21 @@ void TranslatorWidget::init()
     layout->addWidget(d->splitter);
 
     d->initLanguage();
-    connect(d->from, static_cast<void (MinimumComboBox::*)(int)>(&MinimumComboBox::currentIndexChanged), this, &TranslatorWidget::slotConfigChanged);
-
     d->from->setCurrentIndex(0);   //Fill "to" combobox
     slotFromLanguageChanged(0, true);
     slotTextChanged();
     readConfig();
-    connect(d->from, SIGNAL(currentIndexChanged(int)), SLOT(slotFromLanguageChanged(int)));
-    connect(d->to, static_cast<void (MinimumComboBox::*)(int)>(&MinimumComboBox::currentIndexChanged), this, &TranslatorWidget::slotTranslate);
+    connect(d->from, QOverload<int>::of(&MinimumComboBox::currentIndexChanged), this, [this](int val) {
+        slotFromLanguageChanged(val, false);
+    });
+    connect(d->from, QOverload<int>::of(&MinimumComboBox::currentIndexChanged), this, &TranslatorWidget::slotConfigChanged);
+
+    connect(d->to, QOverload<int>::of(&MinimumComboBox::currentIndexChanged), this, &TranslatorWidget::slotConfigChanged);
+    connect(d->to, QOverload<int>::of(&MinimumComboBox::currentIndexChanged), this, &TranslatorWidget::slotTranslate);
 
     hide();
     setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
     d->languageSettingsChanged = false;
-
 }
 
 void TranslatorWidget::slotConfigChanged()
@@ -353,7 +352,6 @@ void TranslatorWidget::slotFromLanguageChanged(int index, bool initialize)
 void TranslatorWidget::setTextToTranslate(const QString &text)
 {
     d->inputText->setPlainText(text);
-    d->translatorResultTextEdit->clear();
     slotTranslate();
 }
 
@@ -466,8 +464,5 @@ void TranslatorWidget::slotClear()
 
 void TranslatorWidget::slotDebug()
 {
-#if !defined(NDEBUG)
     d->abstractTranslator->debug();
-#endif
 }
-
