@@ -2,8 +2,9 @@
   Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,11 +29,11 @@ class PIMCOMMON_EXPORT CustomTreeView : public QTreeWidget
     Q_OBJECT
 public:
     explicit CustomTreeView(QWidget *parent = nullptr);
-    ~CustomTreeView();
+    ~CustomTreeView() override;
 
     void setDefaultText(const QString &text);
 
-    bool showDefaultText() const;
+    Q_REQUIRED_RESULT bool showDefaultText() const;
     void setShowDefaultText(bool b);
 
 private:
