@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -37,18 +38,16 @@ public:
     ManageServerSideSubscriptionJobPrivate()
         : mParentWidget(nullptr)
     {
-
     }
 
     Akonadi::Collection mCurrentCollection;
-    QWidget *mParentWidget;
+    QWidget *mParentWidget = nullptr;
 };
 
 ManageServerSideSubscriptionJob::ManageServerSideSubscriptionJob(QObject *parent)
-    : QObject(parent),
-      d(new PimCommon::ManageServerSideSubscriptionJobPrivate)
+    : QObject(parent)
+    , d(new PimCommon::ManageServerSideSubscriptionJobPrivate)
 {
-
 }
 
 ManageServerSideSubscriptionJob::~ManageServerSideSubscriptionJob()
@@ -65,12 +64,12 @@ void ManageServerSideSubscriptionJob::start()
     }
     bool isImapOnline = false;
     if (PimCommon::MailUtil::isImapFolder(d->mCurrentCollection, isImapOnline)) {
-        const QString service =
-            Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource,
-                                                     d->mCurrentCollection.resource());
+        const QString service
+            = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource,
+                                                       d->mCurrentCollection.resource());
         QDBusInterface iface(service,
-            QStringLiteral("/"), QStringLiteral("org.kde.Akonadi.ImapResourceBase"),
-            KDBusConnectionPool::threadConnection(), this);
+                             QStringLiteral("/"), QStringLiteral("org.kde.Akonadi.ImapResourceBase"),
+                             KDBusConnectionPool::threadConnection(), this);
         if (!iface.isValid()) {
             qCDebug(PIMCOMMONAKONADI_LOG) << "Cannot create imap dbus interface for service " << service;
             deleteLater();
